==> sg3_utils-1.31-i486-70.1.txz: usr/src/sg3_utils-1.31/build-sg3_utils.sh <==
#!/bin/bash
#
# Sources: http://sg.danny.cz/sg/p/sg3_utils-1.31.tgz
#
# Maintainer: gmg (g.monpontet@gmail.com)
# 

soft="sg3_utils"
softversion="1.31"
packageversion="70.1"
arch="i486"
cpu="i686"
buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tgz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

cd $buildir
rm -rf $src
tar -xvzf $srcpkg
rm -f $dest.tgz
rm -rf $dest

cd $src
chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
./configure \
  --prefix=/usr \
  --mandir=/usr/man \
  --disable-static

make -j4
make install DESTDIR=$dest

find $dest | xargs file | grep -e "shared object" -e "executable" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

( cd $dest/usr/man
  find . -type f -exec gzip -9 {} \;
  for i in $(find . -type l) ; do ln -s $(readlink $i).gz $i.gz ; rm $i ; done
)

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a AUTHORS ChangeLog COPYING COVERAGE CREDITS NEWS README TODO $dest/usr/doc/$soft-$softversion

mkdir -p $dest/install
cat << EOF > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

         |-----handy-ruler------------------------------------------------------|
sg3_utils: Sg3_utils - contains utilities that send SCSI commands to devices
sg3_utils:
sg3_utils: The sg3_utils package contains utilities that send SCSI commands to
sg3_utils: devices. As well as devices on transports traditionally associated
sg3_utils: with SCSI (e.g. Fibre Channel (FCP), Serial Attached SCSI (SAS) and
sg3_utils: the SCSI Parallel Interface(SPI)) many other devices use SCSI command
sg3_utils: sets. ATAPI cd/dvd drives and SATA disks that connect via a translation
sg3_utils: layer or a bridge device are examples of devices that use SCSI command
sg3_utils: sets.
sg3_utils:
sg3_utils:
EOF

mkdir -p $dest/usr/src/$soft-$softversion
cp -a $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#-------------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.txz

cd $buildir
md5sum $package.txz > $package.md5

==> sg3_utils-1.33-i486-72.1.txz: usr/src/sg3_utils-1.33/build-sg3_utils.sh <==
#!/bin/bash
#
# Sources: http://sg.danny.cz/sg/p/sg3_utils-1.33.tar.xz
#
# Maintainer: gmg (g.monpontet@gmail.com)
# 

soft="sg3_utils"
softversion="1.33"
packageversion="72.1"
arch="i486"
cpu="i686"
buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.xz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.txz
rm -rf $dest

cd $src
chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
./configure \
  --prefix=/usr \
  --mandir=/usr/man \
  --disable-static

make -j4
make install DESTDIR=$dest

find $dest | xargs file | grep -e "shared object" -e "executable" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

( cd $dest/usr/man
  find . -type f -exec gzip -9 {} \;
  for i in $(find . -type l) ; do ln -s $(readlink $i).gz $i.gz ; rm $i ; done
)

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a AUTHORS ChangeLog COPYING COVERAGE CREDITS NEWS README TODO $dest/usr/doc/$soft-$softversion

mkdir -p $dest/install
cat << EOF > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

         |-----handy-ruler------------------------------------------------------|
sg3_utils: Sg3_utils - contains utilities that send SCSI commands to devices
sg3_utils:
sg3_utils: The sg3_utils package contains utilities that send SCSI commands to
sg3_utils: devices. As well as devices on transports traditionally associated
sg3_utils: with SCSI (e.g. Fibre Channel (FCP), Serial Attached SCSI (SAS) and
sg3_utils: the SCSI Parallel Interface(SPI)) many other devices use SCSI command
sg3_utils: sets. ATAPI cd/dvd drives and SATA disks that connect via a translation
sg3_utils: layer or a bridge device are examples of devices that use SCSI command
sg3_utils: sets.
sg3_utils:
sg3_utils:
EOF

mkdir -p $dest/usr/src/$soft-$softversion
cp -a $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#-------------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.txz

cd $buildir
md5sum $package.txz > $package.md5
